@@ -2,7 +2,7 @@
  * main.c
  * main() routine, printer functions
  *
- * Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+ * Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019
  *     pkgconf authors (see AUTHORS).
  *
  * Permission to use, copy, modify, and/or distribute this software for any
@@ -14,11 +14,13 @@
  * from the use of this software.
  */
 
+#include "libpkgconf/config.h"
 #include <libpkgconf/stdinc.h>
 #include <libpkgconf/libpkgconf.h>
-#include "libpkgconf/config.h"
 #include "getopt_long.h"
+#ifndef PKGCONF_LITE
 #include "renderer-msvc.h"
+#endif
 #ifdef _WIN32
 #include <io.h>     /* for _setmode() */
 #include <fcntl.h>
@@ -246,6 +248,7 @@ apply_provides(pkgconf_client_t *client, pkgconf_pkg_t *world, void *unused, int
 	return true;
 }
 
+#ifndef PKGCONF_LITE
 static void
 print_digraph_node(pkgconf_client_t *client, pkgconf_pkg_t *pkg, void *unused)
 {
@@ -280,6 +283,7 @@ apply_digraph(pkgconf_client_t *client, pkgconf_pkg_t *world, void *unused, int
 	printf("}\n");
 	return true;
 }
+#endif
 
 static bool
 apply_modversion(pkgconf_client_t *client, pkgconf_pkg_t *world, void *unused, int maxdepth)
@@ -542,6 +546,7 @@ apply_uninstalled(pkgconf_client_t *client, pkgconf_pkg_t *world, void *data, in
 	return true;
 }
 
+#ifndef PKGCONF_LITE
 static void
 print_graph_node(pkgconf_client_t *client, pkgconf_pkg_t *pkg, void *data)
 {
@@ -585,6 +590,7 @@ apply_simulate(pkgconf_client_t *client, pkgconf_pkg_t *world, void *data, int m
 
 	return true;
 }
+#endif
 
 static void
 version(void)
@@ -596,7 +602,7 @@ static void
 about(void)
 {
 	printf("%s %s\n", PACKAGE_NAME, PACKAGE_VERSION);
-	printf("Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018\n");
+	printf("Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019\n");
 	printf("    pkgconf authors (see AUTHORS in documentation directory).\n\n");
 	printf("Permission to use, copy, modify, and/or distribute this software for any\n");
 	printf("purpose with or without fee is hereby granted, provided that the above\n");
@@ -625,7 +631,9 @@ usage(void)
 	printf("  --silence-errors                  explicitly be silent about errors\n");
 	printf("  --list-all                        list all known packages\n");
 	printf("  --list-package-names              list all known package names\n");
+#ifndef PKGCONF_LITE
 	printf("  --simulate                        simulate walking the calculated dependency graph\n");
+#endif
 	printf("  --no-cache                        do not cache already seen packages when\n");
 	printf("                                    walking the dependency graph\n");
 	printf("  --log-file=filename               write an audit log to a specified file\n");
@@ -638,9 +646,11 @@ usage(void)
 	printf("  --relocate=path                   relocates a path and exits (mostly for testsuite)\n");
 	printf("  --dont-relocate-paths             disables path relocation support\n");
 
+#ifndef PKGCONF_LITE
 	printf("\ncross-compilation personality support:\n\n");
 	printf("  --personality=triplet|filename    sets the personality to 'triplet' or a file named 'filename'\n");
 	printf("  --dump-personality                dumps details concerning selected personality\n");
+#endif
 
 	printf("\nchecking specific pkg-config database entries:\n\n");
 
@@ -676,7 +686,9 @@ usage(void)
 	printf("                                    linking to stdout\n");
 	printf("  --print-provides                  print provided dependencies to stdout\n");
 	printf("  --print-variables                 print all known variables in module to stdout\n");
+#ifndef PKGCONF_LITE
 	printf("  --digraph                         print entire dependency graph in graphviz 'dot' format\n");
+#endif
 	printf("  --keep-system-cflags              keep -I%s entries in cflags output\n", SYSTEM_INCLUDEDIR);
 	printf("  --keep-system-libs                keep -L%s entries in libs output\n", SYSTEM_LIBDIR);
 	printf("  --path                            show the exact filenames for any matching .pc files\n");
@@ -684,7 +696,9 @@ usage(void)
 	printf("  --internal-cflags                 do not filter 'internal' cflags from output\n");
 
 	printf("\nfiltering output:\n\n");
+#ifndef PKGCONF_LITE
 	printf("  --msvc-syntax                     print translatable fragments in MSVC syntax\n");
+#endif
 	printf("  --fragment-filter=types           filter output fragments to the specified types\n");
 
 	printf("\nreport bugs to <%s>.\n", PACKAGE_BUGREPORT);
@@ -701,6 +715,7 @@ relocate_path(const char *path)
 	printf("%s\n", buf);
 }
 
+#ifndef PKGCONF_LITE
 static void
 dump_personality(const pkgconf_cross_personality_t *p)
 {
@@ -758,7 +773,7 @@ deduce_personality(char *argv[])
 	if (i == NULL)
 		return pkgconf_cross_personality_default();
 
-	prefix = strndup(argv0, i - argv0);
+	prefix = pkgconf_strndup(argv0, i - argv0);
 	out = pkgconf_cross_personality_find(prefix);
 	free(prefix);
 	if (out == NULL)
@@ -766,6 +781,7 @@ deduce_personality(char *argv[])
 
 	return out;
 }
+#endif
 
 int
 main(int argc, char *argv[])
@@ -814,7 +830,9 @@ main(int argc, char *argv[])
 		{ "pure", no_argument, &want_flags, PKG_PURE, },
 		{ "print-requires", no_argument, &want_flags, PKG_REQUIRES, },
 		{ "print-variables", no_argument, &want_flags, PKG_VARIABLES|PKG_PRINT_ERRORS, },
+#ifndef PKGCONF_LITE
 		{ "digraph", no_argument, &want_flags, PKG_DIGRAPH, },
+#endif
 		{ "help", no_argument, &want_flags, PKG_HELP, },
 		{ "env-only", no_argument, &want_flags, PKG_ENV_ONLY, },
 		{ "print-requires-private", no_argument, &want_flags, PKG_REQUIRES_PRIVATE, },
@@ -835,7 +853,9 @@ main(int argc, char *argv[])
 		{ "silence-errors", no_argument, &want_flags, PKG_SILENCE_ERRORS, },
 		{ "list-all", no_argument, &want_flags, PKG_LIST|PKG_PRINT_ERRORS, },
 		{ "list-package-names", no_argument, &want_flags, PKG_LIST_PACKAGE_NAMES|PKG_PRINT_ERRORS, },
+#ifndef PKGCONF_LITE
 		{ "simulate", no_argument, &want_flags, PKG_SIMULATE, },
+#endif
 		{ "no-cache", no_argument, &want_flags, PKG_NO_CACHE, },
 		{ "print-provides", no_argument, &want_flags, PKG_PROVIDES, },
 		{ "no-provides", no_argument, &want_flags, PKG_NO_PROVIDES, },
@@ -850,21 +870,31 @@ main(int argc, char *argv[])
 		{ "dont-define-prefix", no_argument, &want_flags, PKG_DONT_DEFINE_PREFIX },
 		{ "dont-relocate-paths", no_argument, &want_flags, PKG_DONT_RELOCATE_PATHS },
 		{ "env", required_argument, NULL, 48 },
+#ifndef PKGCONF_LITE
 		{ "msvc-syntax", no_argument, &want_flags, PKG_MSVC_SYNTAX },
+#endif
 		{ "fragment-filter", required_argument, NULL, 50 },
 		{ "internal-cflags", no_argument, &want_flags, PKG_INTERNAL_CFLAGS },
+#ifndef PKGCONF_LITE
 		{ "dump-personality", no_argument, &want_flags, PKG_DUMP_PERSONALITY },
 		{ "personality", required_argument, NULL, 53 },
+#endif
 		{ NULL, 0, NULL, 0 }
 	};
 
+#ifndef PKGCONF_LITE
 	if (getenv("PKG_CONFIG_EARLY_TRACE"))
 	{
 		error_msgout = stderr;
 		pkgconf_client_set_trace_handler(&pkg_client, error_handler, NULL);
 	}
+#endif
 
+#ifndef PKGCONF_LITE
 	personality = deduce_personality(argv);
+#else
+	personality = pkgconf_cross_personality_default();
+#endif
 
 	while ((ret = pkg_getopt_long_only(argc, argv, "", options, NULL)) != -1)
 	{
@@ -909,9 +939,11 @@ main(int argc, char *argv[])
 		case 50:
 			want_fragment_filter = pkg_optarg;
 			break;
+#ifndef PKGCONF_LITE
 		case 53:
 			personality = pkgconf_cross_personality_find(pkg_optarg);
 			break;
+#endif
 		case '?':
 		case ':':
 			return EXIT_FAILURE;
@@ -924,17 +956,21 @@ main(int argc, char *argv[])
 	pkgconf_path_copy_list(&personality->dir_list, &dir_list);
 	pkgconf_path_free(&dir_list);
 
+#ifndef PKGCONF_LITE
 	if ((want_flags & PKG_DUMP_PERSONALITY) == PKG_DUMP_PERSONALITY)
 	{
 		dump_personality(personality);
 		return EXIT_SUCCESS;
 	}
+#endif
 
 	/* now, bring up the client.  settings are preserved since the client is prealloced */
 	pkgconf_client_init(&pkg_client, error_handler, NULL, personality);
 
+#ifndef PKGCONF_LITE
 	if ((want_flags & PKG_MSVC_SYNTAX) == PKG_MSVC_SYNTAX)
 		want_render_ops = msvc_renderer_get();
+#endif
 
 	if ((env_traverse_depth = getenv("PKG_CONFIG_MAXIMUM_TRAVERSE_DEPTH")) != NULL)
 		maximum_traverse_depth = atoi(env_traverse_depth);
@@ -953,8 +989,10 @@ main(int argc, char *argv[])
 	if ((want_flags & PKG_VALIDATE) == PKG_VALIDATE || (want_flags & PKG_DEBUG) == PKG_DEBUG)
 		pkgconf_client_set_warn_handler(&pkg_client, error_handler, NULL);
 
+#ifndef PKGCONF_LITE
 	if ((want_flags & PKG_DEBUG) == PKG_DEBUG)
 		pkgconf_client_set_trace_handler(&pkg_client, error_handler, NULL);
+#endif
 
 	if ((want_flags & PKG_ABOUT) == PKG_ABOUT)
 	{
@@ -1241,6 +1279,7 @@ main(int argc, char *argv[])
 
 	ret = EXIT_SUCCESS;
 
+#ifndef PKGCONF_LITE
 	if ((want_flags & PKG_SIMULATE) == PKG_SIMULATE)
 	{
 		want_flags &= ~(PKG_CFLAGS|PKG_LIBS);
@@ -1252,6 +1291,7 @@ main(int argc, char *argv[])
 			goto out;
 		}
 	}
+#endif
 
 	if (!pkgconf_queue_validate(&pkg_client, &pkgq, maximum_traverse_depth))
 	{
@@ -1291,6 +1331,7 @@ main(int argc, char *argv[])
 		}
 	}
 
+#ifndef PKGCONF_LITE
 	if ((want_flags & PKG_DIGRAPH) == PKG_DIGRAPH)
 	{
 		want_flags &= ~(PKG_CFLAGS|PKG_LIBS);
@@ -1301,6 +1342,7 @@ main(int argc, char *argv[])
 			goto out;
 		}
 	}
+#endif
 
 	if ((want_flags & PKG_MODVERSION) == PKG_MODVERSION)
 	{
