@@ -41,6 +41,10 @@ extern "C" {
 #define PKG_DIR_SEP_S   '/'
 #endif
 
+#ifdef _WIN32
+#define realpath(N,R) _fullpath((R),(N),_MAX_PATH)
+#endif
+
 #define PKGCONF_BUFSIZE	(65535)
 
 typedef enum {
@@ -74,8 +78,8 @@ typedef struct pkgconf_cross_personality_ pkgconf_cross_personality_t;
 #define PKGCONF_FOREACH_LIST_ENTRY_REVERSE(tail, value) \
 	for ((value) = (tail); (value) != NULL; (value) = (value)->prev)
 
-#define LIBPKGCONF_VERSION	10600
-#define LIBPKGCONF_VERSION_STR	"1.6.0"
+#define LIBPKGCONF_VERSION	10603
+#define LIBPKGCONF_VERSION_STR	"1.6.3"
 
 struct pkgconf_fragment_ {
 	pkgconf_node_t iter;
@@ -274,6 +278,7 @@ PKGCONF_API bool pkgconf_warn(const pkgconf_client_t *client, const char *format
 PKGCONF_API bool pkgconf_trace(const pkgconf_client_t *client, const char *filename, size_t lineno, const char *funcname, const char *format, ...) PRINTFLIKE(5, 6);
 PKGCONF_API bool pkgconf_default_error_handler(const char *msg, const pkgconf_client_t *client, const void *data);
 
+#ifndef PKGCONF_LITE
 #if defined(__GNUC__) || defined(__INTEL_COMPILER)
 #define PKGCONF_TRACE(client, ...) do { \
 		pkgconf_trace(client, __FILE__, __LINE__, __PRETTY_FUNCTION__, __VA_ARGS__); \
@@ -283,6 +288,9 @@ PKGCONF_API bool pkgconf_default_error_handler(const char *msg, const pkgconf_cl
 		pkgconf_trace(client, __FILE__, __LINE__, __func__, __VA_ARGS__); \
 	} while (0);
 #endif
+#else
+#define PKGCONF_TRACE(client, ...)
+#endif
 
 PKGCONF_API pkgconf_pkg_t *pkgconf_pkg_ref(pkgconf_client_t *client, pkgconf_pkg_t *pkg);
 PKGCONF_API void pkgconf_pkg_unref(pkgconf_client_t *client, pkgconf_pkg_t *pkg);
