@@ -13,9 +13,9 @@
  * from the use of this software.
  */
 
+#include <libpkgconf/config.h>
 #include <libpkgconf/stdinc.h>
 #include <libpkgconf/libpkgconf.h>
-#include <libpkgconf/config.h>
 
 #if defined(HAVE_CYGWIN_CONV_PATH) && defined(__MSYS__)
 # include <sys/cygwin.h>
@@ -95,7 +95,12 @@ pkgconf_path_add(const char *text, pkgconf_list_t *dirlist, bool filter)
 			char *linkdest = realpath(path, NULL);
 
 			if (linkdest != NULL && stat(linkdest, &st) == -1)
+			{
+				free(linkdest);
 				return;
+			}
+
+			free(linkdest);
 		}
 		if (path_list_contains_entry(path, dirlist, &st))
 			return;
