@@ -21,7 +21,7 @@ do
 done
 #--- end kludge ---
 
-selfdir="/Users/kaniini/dev-src/pkgconf/tests"
+selfdir="/home/kaniini/pkgconf/tests"
 LIBRARY_PATH_ENV="LIBRARY_PATH"
 PATH_SEP=":"
 SYSROOT_DIR="${selfdir}/test"
@@ -30,7 +30,7 @@ Msys|CYGWIN*) PATH_SEP=";";;
 Haiku) LIBRARY_PATH_ENV="BELIBRARIES";;
 esac
 
-prefix="/usr"
+prefix="/usr/local"
 exec_prefix="${prefix}"
 datarootdir="${prefix}/share"
 pcpath="${exec_prefix}/lib/pkgconfig:${datarootdir}/pkgconfig"
